import { defHttp } from '@/utils/axios/index'
import { ContentTypeEnum } from '@/enums/httpEnums'
import type { ApiResult, ApiResultRecord } from '../model/baseModel'
import type { UserInfo } from './model/userModel'

enum Api {
  userList = '/user/findUserPage',
  userInDelete = '/user/delete',
  userInsert = '/user/save',
  userFindById = '/user/findById',
  userUpdate = '/user/update',
  userRoleAuth = '/userRole/save'
}

export const apiQueryUserList = (data: any) => {
  return defHttp.post<ApiResult<ApiResultRecord<UserInfo[]>>>({
    url: Api.userList,
    data
  })
}

export const apiDeleteUser = (params: { userIds: string }) => {
  return defHttp.delete<ApiResult>({
    url: Api.userInDelete,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiInsertUser = (data: UserInfo) => {
  return defHttp.post<ApiResult<UserInfo>>({
    url: Api.userInsert,
    data
  })
}

export const apiFindByIdUser = (params: { id: string }) => {
  return defHttp.get<ApiResult<UserInfo>>({
    url: Api.userFindById,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiUpdateUser = (data: UserInfo) => {
  return defHttp.post<ApiResult<UserInfo>>({
    url: Api.userUpdate,
    data
  })
}

export const apiUserRoleAuth = (params: any) => {
  return defHttp.post<ApiResult>({
    url: Api.userRoleAuth,
    params,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
