import { apiUserLogin } from '@/api/common/login'
import type { LoginParams } from '@/api/common/model/loginModel'
import type { UserInfo } from '@/api/sys/model/userModel'
import { Modal, message } from 'ant-design-vue'
import { defineStore } from 'pinia'
import { usePermissionStore } from './permission'
import { router } from '@/router'
import { createVNode } from 'vue'
import { ExclamationCircleOutlined } from '@ant-design/icons-vue'

interface UserState {
  userInfo: Nullable<UserInfo>
  userName: string
  token?: string
}

export const useUserStore = defineStore('app-user', {
  state: (): UserState => ({
    // token
    token: undefined,
    // user info
    userInfo: null,
    userName: ''
  }),
  getters: {
    getToken(): string {
      return this.token || ''
    },
    getUserInfo(): Nullable<UserInfo> {
      return this.userInfo
    }
  },
  actions: {
    setUserName(userName: string) {
      this.userName = userName
    },
    setToken(token?: string) {
      this.token = token
    },
    setUserInfo(userInfo: any) {
      this.userInfo = userInfo
    },
    resetState() {
      this.userInfo = null
      this.token = ''
    },
    async getUserInfoAction() {},
    async login(params: LoginParams) {
      try {
        // 登录
        const {result} = await apiUserLogin(params)

        // 设置token
        this.setToken(result.token)
        this.setUserName(result.username)

        await this.afterLoginAction()
        message.success('登录成功，欢迎进入！')
        router.replace('/')
      } catch(error) {
        return Promise.reject(error);
      }
    },
    async afterLoginAction() {
      if (!this.getToken) return null
      console.log('afterLoginAction')

      const permissionStore = usePermissionStore();
      const routes = await permissionStore.buildRoutesAction();
      routes.forEach(_route => {
        router.addRoute(_route)
      })
      permissionStore.setIsDynamicAddedRoute(true)
      return true
    },
    /**
     * @description: logout
     */
    async logout(goLogin = false) {
      if (this.getToken) {
        try {
          // await doLogout();
        } catch {
          console.log('注销Token失败');
        }
      }
      this.setToken(undefined);
      this.setUserInfo(null);
      goLogin && router.push('/login')
    },
    /**
     * @description: Confirm before logging out
     */
    confirmLoginOut() {
      Modal.confirm({
        title: '温馨提醒',
        icon: createVNode(ExclamationCircleOutlined),
        content: '是否确认退出系统?',
        okText: '确认',
        cancelText: '取消',
        onOk: () => this.logout(true)
      })

    },
  },
  persist: {
    storage: localStorage
  }
})
