import {
  apiInsertMenu,
  apiGetMenuList,
  apiUpdateMenu,
  apiGetMenuListTree,
  apiFindMenuById,
  apiDeleteMenuById
} from '@/api/sys/menu'
import type { MenuPermissionDto, MenuPermissionInfo } from '@/api/sys/model/menuModel'
import { message } from 'ant-design-vue'
import type { Rule } from 'ant-design-vue/es/form'
import { computed, onMounted, reactive, ref, unref, watch } from 'vue'
import type { VxeTableInstance } from 'vxe-table'

const initFormState = (): MenuPermissionDto => {
  return {
    permissionType: '0',
    pid: '',
    permissionUrl: '',
    permissionName: '',
    permissionIcon: '',
    internalOrExternal: 0,
    permissionComponent: '',
    permissionComponentName: '',
    permissionCode: '',
    keepAlive: 1,
    sequence: 1,
    hidden: 0,
    permsType: 1,
    orgCode: '',
    permissionDes: '',
    permissionRedirect: '',
    permissionHasRoute: 1,
    hideTab: 0
  }
}

const rules: Record<string, Rule[]> = {
  permissionName: [{ required: true, message: '请输入菜单名称', trigger: 'change' }],
  sequence: [{ required: true, message: '请输入显示排序', trigger: 'change' }],
  permissionUrl: [{ required: true, message: '请输入菜单路径', trigger: 'change' }]
}

export function useMenuPage() {
  const tableRef = ref<VxeTableInstance<MenuPermissionInfo>>()
  const tableData = ref<MenuPermissionInfo[]>([])
  const loading = ref(false)

  onMounted(() => {
    queryData()
  })

  /**
   * TODO:查询未添加查询条件
   */
  const queryData = async () => {
    loading.value = true
    try {
      const { result } = await apiGetMenuList()
      tableData.value = result
    } catch (e) {}
    loading.value = false
  }

  return {
    tableRef,
    tableData,
    loading,
    queryData
  }
}

export function useMenuForm() {
  const menuFormRef = ref()
  const menuFormRules = reactive<Record<string, Rule[]>>(rules)
  const menuFormState = reactive<MenuPermissionDto & { permissionId?: string }>(initFormState())
  const addLoading = ref(false)

  const validate = async () => await menuFormRef.value.validate()
  const resetFrom = (flag = false) => {
    const state = initFormState()
    flag && (state.permissionType = menuFormState.permissionType)
    Object.assign(unref(menuFormState), state, {permissionId: ''})
  }

  const isDir = computed(() => menuFormState.permissionType === '0')
  const isMenu = computed(() => menuFormState.permissionType === '1')
  const isBtn = computed(() => menuFormState.permissionType === '2')
  const isModify = computed(() => !!menuFormState?.permissionId)

  const permissionTypeChange = () => {
    menuFormRef.value?.clearValidate()
    resetFrom(true)
  }
  //   watch(
  //     () => menuFormState.permissionType,
  //     () => {
  //       menuFormRef.value?.clearValidate()
  //       resetFrom(true)
  //     }
  //   )

  const getMenuInfo = async (id: string) => {
    const { result } = await apiFindMenuById({ id })
    Object.assign(unref(menuFormState), result)
  }

  const removeMenu = async (ids: string) => {
    try {
      await apiDeleteMenuById({ ids })
      message.success('删除成功')
    } catch (e) {
      Promise.reject(e)
    }
  }

  const submitForm = async () => {
    await validate()
    isModify.value ? await apiUpdateMenu(menuFormState) : await apiInsertMenu(menuFormState)
    message.success('保存成功')
  }

  return {
    menuFormRef,
    menuFormRules,
    menuFormState,
    addLoading,
    isDir,
    isMenu,
    isBtn,
    isModify,
    removeMenu,
    permissionTypeChange,
    getMenuInfo,
    submitForm,
    resetFrom
  }
}

export function useTree() {
  const treeData = ref<MenuPermissionInfo[]>([])

  const onLoadData = async () => {
    const { result } = await apiGetMenuListTree()

    treeData.value = result
  }

  onMounted(() => {
    onLoadData()
  })

  return {
    treeData,
    onLoadData
  }
}
